import { BiliCredential } from "./biliCredential";
import { Btype } from "./types/common";
import { AddResponse, SortBy, ListResponse, CommonResponse } from "./types/comment";
/**
 * 评论区
 */
export declare class Comment {
    oid?: string | undefined;
    type?: Btype | undefined;
    private credential;
    constructor(credential: BiliCredential, oid?: string | undefined, type?: Btype | undefined);
    /**
     * 发送评论
     * @param oid 评论区id
     * @param message 回复内容
     * @param type 评论区类型
     * @returns
     */
    add(message: string): Promise<AddResponse>;
    /**
     * 发送回复
     * @param oid 评论区id
     * @param type 评论区类型
     * @param root 回复串根
     * @param parent 想要回复的那条回复
     * @param message 回复内容
     * @returns
     */
    reply(root: number, parent: number, message: string): Promise<AddResponse>;
    /**
     * 删除一条回复
     * @param oid 评论区id
     * @param reply_id 回复id
     * @param type 评论区类型
     * @returns
     */
    delete(reply_id: string): Promise<CommonResponse>;
    /**
     * 置顶一条回复
     * @param oid 评论区id
     * @param reply_id 回复id
     * @param type 评论区类型
     * @returns
     */
    top(reply_id: string, actionL: true): Promise<CommonResponse>;
    /**
     * 列出评论区
     * @param oid 评论区id
     * @param type 评论区类型
     * @param page_num 评论区页数
     * @returns
     */
    list(page_num: number, sort: SortBy): Promise<ListResponse>;
    /**
     * 点赞评论、回复
     * @param oid 评论区类型
     * @param action 操作
     * @param type 	评论区类型
     * @returns
     */
    like(rpid: string, action: boolean): Promise<boolean>;
    /**
     * 踩评论、回复
     * @param oid 评论区类型
     * @param action 操作
     * @param type 评论区类型
     * @returns
     */
    hate(rpid: string, action: true): Promise<boolean>;
}
//# sourceMappingURL=comment.d.ts.map