"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Comment = void 0;
const request_1 = require("./request");
/**
 * 评论区
 */
class Comment {
    constructor(credential, oid, type) {
        this.oid = oid;
        this.type = type;
        this.credential = credential;
    }
    async add(message, oid, type) {
        oid = oid ?? this.oid;
        type = type ?? this.type;
        if (!oid || !type)
            throw "需要提供oid和type";
        let payload = {
            oid,
            message,
            type,
            plat: 1,
            ordering: "heat",
            jsonp: "jsonp",
            csrf: this.credential.csfr,
        };
        return request_1.Request.post("https://api.bilibili.com/x/v2/reply/add", payload, this.credential).then(res => { return res; });
    }
    async reply(root, parent, message, oid, type) {
        oid = oid ?? this.oid;
        type = type ?? this.type;
        if (!oid || !type)
            throw "需要提供oid和type";
        let payload = {
            oid,
            message,
            type,
            root,
            parent,
            plat: 1,
            ordering: "heat",
            jsonp: "jsonp",
            csrf: this.credential.csfr,
        };
        return request_1.Request.post("https://api.bilibili.com/x/v2/reply/add", payload, this.credential).then(res => { return res; });
    }
    async delete(reply_id, oid, type) {
        oid = oid ?? this.oid;
        type = type ?? this.type;
        if (!oid || !type)
            throw "需要提供oid和type";
        return request_1.Request.post("https://api.bilibili.com/x/v2/reply/del", {
            oid: oid,
            rpid: reply_id,
            type: type,
            jsonp: "jsonp",
            csrf: this.credential.csfr,
        }, this.credential);
    }
    async top(reply_id, action, oid, type) {
        oid = oid ?? this.oid;
        type = type ?? this.type;
        if (!oid || !type)
            throw "需要提供oid和type";
        return request_1.Request.post("https://api.bilibili.com/x/v2/reply/top", {
            oid,
            rpid: reply_id,
            type,
            action: action ? 1 : 0,
            jsonp: "jsonp",
            csrf: this.credential.csfr,
        }, this.credential);
    }
    async list(page_num = 0, sort = 1 /* SortBy.like */, oid, type) {
        oid = oid ?? this.oid;
        type = type ?? this.type;
        if (!oid || !type)
            throw "需要提供oid和type";
        return request_1.Request.get("https://api.bilibili.com/x/v2/reply", {
            pn: page_num,
            type: type,
            oid: oid,
            sort: sort
        }, this.credential).then(res => {
            console.log(Object.keys(res));
            return res.data.data;
        });
    }
    async like(rpid, action = true, oid, type) {
        oid = oid ?? this.oid;
        type = type ?? this.type;
        if (!oid || !type)
            throw "需要提供oid和type";
        return request_1.Request.get("https://api.bilibili.com/x/v2/reply/action", {
            oid,
            type,
            rpid,
            action: action ? 1 : 0,
            ordering: "heat",
            jsonp: "jsonp",
        }, this.credential).then(res => { return res.code === 0; });
    }
    async hate(rpid, action = true, oid, type) {
        oid = oid ?? this.oid;
        type = type ?? this.type;
        if (!oid || !type)
            throw "需要提供oid和type";
        return request_1.Request.get("http://api.bilibili.com/x/v2/reply/hate", {
            oid,
            type,
            rpid,
            action: action ? 1 : 0,
            ordering: "heat",
            jsonp: "jsonp",
        }, this.credential).then(res => { return res.code === 0; });
    }
}
exports.Comment = Comment;
// import { MongoClient } from "mongodb";
// const mongodb = new MongoClient("mongodb://127.0.0.1:27017");
// const oid = "554356059";
// const c = new Comment(new BiliCredential("", "", ""), oid, 1)
// interface NewConten extends Content {
//     ipv6?: string
// }
// async function readNload(): Promise<Number> {
//     return c.list(0, SortBy.like).then(async res => {
//         let ipArray = [];
//         for (const reply of res.replies) {
//             if ("ipv6" in reply.content) {
//                 const newContent = reply.content as NewConten;
//                 ipArray.push({
//                     mid: reply.member.mid,
//                     name: reply.member.uname,
//                     ip: newContent.ipv6
//                 });
//             }
//         }
//         if (ipArray.length > 0) {
//             const client = await mongodb.connect();
//             const db = client.db("bilibili");
//             const collection = db.collection(oid);
//             await collection.insertMany([...ipArray]);
//             console.log(`导入了${ipArray.length}条信息`);
//             await client.close();
//             return 0;
//         }
//         else {
//             console.log("一个都没有");
//             return 1;
//         };
//     }).catch(err => {
//         console.error(err);
//         return -1;
//     })
// }
// readNload()
//# sourceMappingURL=comment.js.map