/// <reference types="node" />
/// <reference types="node" />
import { ReadStream } from "fs-extra";
import { BiliCredential } from "./biliCredential";
import { CreateResponse, RepostResponse, DynamiDetail, CreateDraftResponse, PublishDraftResponse, RmDraftResponse, GetDraftsResponse, PreJudgeResp } from "./types/dynamic";
/**
 * 动态
 */
export declare class Dynamic {
    private credential;
    constructor(credential: BiliCredential);
    /**
     * 获取动态内容
     * @param dynamic_id 动态id
     * @returns
     */
    static detail(dynamic_id: string): Promise<DynamiDetail>;
    /**
     * 发送动态
     * @param text 动态文字
     * @param images 动态图片
     * @param publish_time 发布时间
     * @returns
     */
    create(text: string, images?: Array<string | Buffer | ReadStream>): Promise<CreateResponse>;
    create(text: string, images: [], publish_time: Date): Promise<CreateDraftResponse>;
    create(text: string, images: Array<string | Buffer | ReadStream>, publish_time: Date): Promise<CreateDraftResponse>;
    /**
     * 发送定时动态
     * @param publish_time 发布时间
     * @param text 动态文字
     * @param images 动态图片
     * @returns
     */
    schduledCreate(publish_time: Date, text: string, images?: Array<string | Buffer | ReadStream>): Promise<CreateDraftResponse>;
    private _dynamicRequest;
    /**
     * 发起投票（开发中不要动）
     * @param title 标题
     * @param options 选项
     * @param opt_images 图片选项
     * @param choice_cnt 最多选择几项
     * @param desc 简介说明
     * @param duration 时长，3天|1周|一个月
     * @returns
     */
    createVote(title: string, options: string[], opt_images?: Array<string | Buffer | ReadStream>, choice_cnt?: number, desc?: string, duration?: 259200 | 604800 | 2592000): Promise<string>;
    /**
     * 删除动态
     * @param dynamic_id 动态id
     * @returns
     */
    remove(dynamic_id: string): Promise<boolean>;
    /**
     * 获取尚未发布的定时动态列表
     * @returns
     */
    getDrafts(): Promise<GetDraftsResponse[]>;
    /**
     * 立即发布定时动态
     * @param draft_id
     */
    publishDraft(draft_id: string): Promise<PublishDraftResponse>;
    /**
     * 删除定时动态
     * @param draft_id 草稿id
     * @returns
     */
    rmDraft(draft_id: string): Promise<RmDraftResponse>;
    /**
     * 检查是否能够发布动态，在发布后调用
     * @param selfuid 自己的uid，不填的话会自动调用BiliCredential中的uid
     * @returns
     */
    preJudge(selfuid?: number): Promise<PreJudgeResp>;
    /**
     * 转发动态
     * @param dynamic_id 动态id
     * @param text 转发文字
     * @returns
     */
    repost(dynamic_id: string, text?: string): Promise<RepostResponse>;
    /**
     * 点赞动态
     * @param dynamic_id 动态id
     * @param action 点赞或取消点赞
     * @returns
     */
    like(dynamic_id: string, action: boolean): Promise<boolean>;
    /**
     * 分享到动态
     * @param rid 视频=av，专栏=cv，音频=au，番剧=eq
     * @param content 来说说分享的理由？|´・ω・)ノ
     * @param type 视频=8，专栏=64，音频=256，自定义=2048，番剧=4097
     * @param up_uid up主uid（可以为0）
     * @returns
     */
    share(rid: string, content: string, type: 8 | 64 | 256 | 2048 | 4097, up_uid?: string): Promise<CreateResponse>;
}
//# sourceMappingURL=dynamic.d.ts.map