/// <reference types="node" />
/// <reference types="node" />
import fs from "fs-extra";
import { BiliCredential } from "./biliCredential";
import { UnreadMsgFeedResp, UnreadPrivateMsgCountResp, ReplyMsgResp, LikeResp, SysMsgResp, MsgBoxResp, MessageFromResp, SendMsgResp } from "./types/message";
/**
 * 收件箱
 */
export declare class Message {
    private credential;
    constructor(credential: BiliCredential);
    /**
     * 获取未读消息数量
     * @returns
     */
    unreadMsgFeed(): Promise<UnreadMsgFeedResp>;
    /**
     * 获取未读私信数量
     * @returns
     */
    unreadPrivateMsgCount(): Promise<UnreadPrivateMsgCountResp>;
    /**
     * 回复我的
     * @returns
     */
    replys(): Promise<ReplyMsgResp>;
    /**
     * 收到的赞
     * @returns
     */
    likes(): Promise<LikeResp>;
    /**
     * 获取系统通知
     * @param cursor 起始位置
     * @returns
     */
    sysMsg(cursor?: string): Promise<SysMsgResp[]>;
    /**
     * 获取私信列表
     * @param end_ts 起始时间戳，以微秒ms计
     * @session_type 消息类型，平时为1，3和5是什么为未知
     * @returns
     */
    messageBox(end_ts?: string, session_type?: 1 | 3 | 5): Promise<MsgBoxResp>;
    /**
     * 标记已读某人消息
     * @param talker_id 发信人uid
     * @returns
     */
    updateAck(talker_id: number): Promise<boolean>;
    /**
     * 获取来自某人的消息
     * @param talker_id 发信人uid
     * @param size 获取数量
     * @param begin_seqno 从第几条开始
     * @param session_type 消息类型
     * @returns
     */
    messageFrom(talker_id: number, size?: number, begin_seqno?: number, session_type?: number): Promise<MessageFromResp>;
    /**
     * 发送私信
     * @param receiver_id 收件人uid
     * @param content 私信内容，发送图片时需要序列化
     * @param msg_type 根据内容而定，文本=1，图片=2，撤回=5
     * @returns
     */
    sendMsg(receiver_id: number, content: string | Buffer | fs.ReadStream, msg_type?: 1 | 2 | 5): Promise<any>;
    /**
     * 撤回私信
     * @param receiver_id 收件人uid
     * @param msg_key 私信消息id
     * @returns
     */
    withdrawMsg(receiver_id: number, msg_key: string): Promise<SendMsgResp>;
}
//# sourceMappingURL=message.d.ts.map