import { BiliCredential } from "./biliCredential";
import { UserInfo, MyInfoResp, UserInfoFromSearch, BatchUserInfosResp, LiveInfoResp } from "./types/user";
/**
 * 用户
 */
export declare class User {
    uid?: number | undefined;
    private credential;
    constructor(credential: BiliCredential, uid?: number | undefined);
    /**
     * 查看用户信息
     * @param mid 用户id
     * @returns
     */
    static info(mid: number): Promise<UserInfo>;
    /**
     * 批量查看用户信息
     * @param uids 用户id
     * @returns
     */
    static batchInfos(uids: number[]): Promise<BatchUserInfosResp[]>;
    /**
     * 获取自己的信息
     * @returns
     */
    static myInfo(credential: BiliCredential): Promise<MyInfoResp>;
    myInfo(): Promise<MyInfoResp>;
    liveInfo(): Promise<LiveInfoResp>;
    /**
     * 用于检查用户id或搜索用户是否存在
     * @param keyword 搜索关键字 / 用户id
     * @returns 返回用户mid，如果不存在则返回0
     */
    static exist(keyword: string | number): Promise<0 | number>;
    /**
     * 根据关键字搜索用户
     * @param keyword 搜索关键字
     * @returns
     */
    static searchUser(keyword: string): Promise<UserInfoFromSearch[]>;
    /**
     * 操作和用户的关系
     * @param act 操作码
     * 关注=1，取关=2，悄悄关注=3，取消悄悄关注=4，拉黑=5，取消拉黑=6，去除粉丝=7
     * @param re_src 来源 空间：11，视频：14，文章：115，活动页面：222
     * @param uid 用户uid
     * @returns
     */
    private _modifyRelation;
    /**
     * 关注/取关用户
     * @param act 操作码，关注=1，取关=2，悄悄关注=3，取消悄悄关注=4
     * @param re_src 来源， 空间：11，视频：14，文章：115，活动页面：222
     * @param uid 用户uid
     * @returns
     */
    follow(act?: 1 | 2 | 3 | 4, re_src?: 11 | 14 | 115 | 222, uid?: number): Promise<boolean>;
    /**
     * 加入，取消黑名单
     * @param act 操作码，加入黑名单=5，取消黑名单=6
     * @param re_src 来源， 空间：11，视频：14，文章：115，活动页面：222
     * @param uid 用户uid
     * @returns
     */
    block(act?: 5 | 6, re_src?: 11 | 14 | 115 | 222, uid?: number): Promise<boolean>;
    /**
     * 删除粉丝
     * @param re_src 来源， 空间：11，视频：14，文章：115，活动页面：222
     * @param uid 用户uid
     * @returns
     */
    rmFan(re_src?: 11 | 14 | 115 | 222, uid?: number): Promise<boolean>;
}
//# sourceMappingURL=user.d.ts.map