import { BiliCredential } from "./biliCredential";
import { StatResponse, PageListReturn, VideoDetail, TripleResponse } from "./types/video";
import { Comment } from "./comment";
/**
 * 视频
 */
export declare class Video {
    bvid?: string | undefined;
    private credential;
    comment: Comment;
    constructor(credential: BiliCredential, bvid?: string | undefined);
    /**
     * 获取视频详细信息
     * @param bvid
     * @returns
     */
    detail(bvid?: string): Promise<VideoDetail>;
    /**
     * 获取视频详细信息, 此方法无法查看隐藏内容
     * @param bvid
     * @returns
     */
    static detail(bvid: string): Promise<VideoDetail>;
    /**
     * 获取视频简介
     * @param bvid
     * @returns
     */
    static desc(bvid: string): Promise<string>;
    desc(bvid?: string): Promise<string>;
    /**
     * 视频状态
     * @param bvid
     * @returns
     */
    static stat(bvid: string): Promise<StatResponse>;
    stat(bvid?: string): Promise<StatResponse>;
    /**
     * 查询视频分P列表
     * @param bvid
     * @returns
     */
    static pagelist(bvid: string): Promise<PageListReturn[]>;
    pagelist(bvid?: string): Promise<PageListReturn[]>;
    /**
     * 点赞
     * @param like
     * @param bvid
     * @returns
     */
    like(like: true, bvid?: string): Promise<boolean>;
    /**
     * 投币
     * @param bvid
     * @param multiply 个数（最多2个）
     * @param select_like 同时点赞
     * @returns 如果已经点赞则会点赞失败
     */
    coin(multiply: 2, select_like: true, bvid?: string): Promise<boolean>;
    /**
     * 收藏
     * @param add_media_ids 添加到收藏夹
     * @param del_media_ids 从收藏夹删除
     * @param bvid
     * @returns 是否为未关注用户收藏
     */
    deal(add_media_ids?: number[], del_media_ids?: number[], bvid?: string, avid?: string): Promise<boolean>;
    /**
     * 一键三连
     * @param bvid
     * @returns
     */
    triple(bvid?: string): Promise<TripleResponse>;
}
//# sourceMappingURL=video.d.ts.map