"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Video = void 0;
const request_1 = require("./request");
const common_1 = require("./common");
const comment_1 = require("./comment");
/**
 * 视频
 */
class Video {
    constructor(credential, bvid) {
        this.bvid = bvid;
        this.credential = credential;
        if (bvid)
            this.comment = new comment_1.Comment(credential, common_1.Common.avBvInterchange(bvid), 1);
    }
    /**
     * 获取视频详细信息
     * @param bvid
     * @returns
     */
    async detail(bvid) {
        bvid = bvid ?? this.bvid;
        if (!bvid)
            throw "需要提供bvid";
        return request_1.Request.get("http://api.bilibili.com/x/web-interface/view", { bvid }, this.credential).then(res => { return res.data; });
    }
    /**
     * 获取视频详细信息, 此方法无法查看隐藏内容
     * @param bvid
     * @returns
     */
    static async detail(bvid) {
        return request_1.Request.get("http://api.bilibili.com/x/web-interface/view", { bvid }).then(res => { return res.data; });
    }
    /**
     * 获取视频简介
     * @param bvid
     * @returns
     */
    static async desc(bvid) {
        return request_1.Request.get("http://api.bilibili.com/x/web-interface/archive/desc", { bvid }).then(res => { return res.data; });
    }
    async desc(bvid) {
        bvid = bvid ?? this.bvid;
        if (!bvid)
            throw "需要提供bvid";
        return Video.desc(bvid);
    }
    /**
     * 视频状态
     * @param bvid
     * @returns
     */
    static async stat(bvid) {
        return request_1.Request.get("https://api.bilibili.com/x/web-interface/archive/stat", { bvid }).then(res => { return res.data; });
    }
    async stat(bvid) {
        bvid = bvid || this.bvid;
        if (!bvid)
            throw "需要提供bvid";
        return Video.stat(bvid);
    }
    /**
     * 查询视频分P列表
     * @param bvid
     * @returns
     */
    static async pagelist(bvid) {
        return request_1.Request.get("http://api.bilibili.com/x/player/pagelist", { bvid }).then(res => { return res.data; });
    }
    async pagelist(bvid) {
        bvid = bvid ?? this.bvid;
        if (!bvid)
            throw "需要提供bvid";
        return Video.pagelist(bvid);
    }
    /**
     * 点赞
     * @param like
     * @param bvid
     * @returns
     */
    async like(like, bvid) {
        bvid = bvid || this.bvid;
        if (!bvid)
            throw "需要提供bvid";
        return request_1.Request.post("https://api.bilibili.com/x/web-interface/archive/like", {
            bvid,
            like: like ? 1 : 2,
            csrf: this.credential.csfr
        }, this.credential).then(res => { return res.code === 0; });
    }
    /**
     * 投币
     * @param bvid
     * @param multiply 个数（最多2个）
     * @param select_like 同时点赞
     * @returns 如果已经点赞则会点赞失败
     */
    async coin(multiply, select_like, bvid) {
        bvid = bvid || this.bvid;
        if (!bvid)
            throw "需要提供bvid";
        return request_1.Request.post("https://api.bilibili.com/x/web-interface/coin/add", {
            bvid,
            multiply,
            select_like,
            csrf: this.credential.csfr
        }, this.credential).then(res => { return res.data.like; });
    }
    /**
     * 收藏
     * @param add_media_ids 添加到收藏夹
     * @param del_media_ids 从收藏夹删除
     * @param bvid
     * @returns 是否为未关注用户收藏
     */
    async deal(add_media_ids, del_media_ids, bvid, avid) {
        let rid = "";
        if (!avid) {
            bvid = bvid || this.bvid;
            if (!bvid)
                throw "需要提供bvid";
            common_1.Common.avBvInterchange(bvid);
        }
        else
            rid = avid;
        return request_1.Request.post("https://api.bilibili.com/x/v3/fav/resource/deal", {
            rid,
            type: 2,
            add_media_ids: add_media_ids?.join(",") ?? "",
            del_media_ids: del_media_ids?.join(",") ?? "",
            csrf: this.credential.csfr
        }, this.credential).then(res => { return res.data.prompt; });
    }
    /**
     * 一键三连
     * @param bvid
     * @returns
     */
    async triple(bvid) {
        bvid = bvid || this.bvid;
        if (!bvid)
            throw "需要提供bvid";
        return request_1.Request.post("http://api.bilibili.com/x/web-interface/archive/like/triple", {
            bvid,
            csrf: this.credential.csfr
        }, this.credential).then(res => { return res.data; });
    }
}
exports.Video = Video;
//# sourceMappingURL=video.js.map